using NUnit.Framework;
using System;
using System.Threading.Tasks;
using UserService.DatabaseLayer.Repositories;
using UserService.Infrastructure.DataModels;

namespace UserService.Test
{
    public class UserRepositoryTests
    {
        private UsersRepository _repository;

        [OneTimeSetUp]
        public void SetUp()
        {
            _repository = new UsersRepository();
        }

        [Test]
        [Order(2)]
        public async Task Test1()
        {
            var users = await _repository.GetAllAsync().ConfigureAwait(false);
            Assert.AreEqual(users.Count, 1);
        }

        [Test]
        [Order(1)]
        public async Task Test2()
        {
            var user = new User
            {
                CommonName = "holger",
                FirstName = "Holger",
                LastName = "Börchers",
                IsActive = true
            };
            await _repository.AddAsync(user).ConfigureAwait(false);
        }

        [Test]
        [Order(3)]
        public async Task Test3()
        {
            var user = await _repository.GetAsync(x => x.CommonName == "holger").ConfigureAwait(false);
            user.Description = DateTime.Now.ToString("O");
            await _repository.UpdateAsync(user).ConfigureAwait(false);
        }

        [Test]
        [Order(4)]
        public async Task Test4()
        {
            var user = await _repository.GetAsync(x => x.CommonName == "holger").ConfigureAwait(false);
            await _repository.DeleteAsync(user).ConfigureAwait(false);
        }
    }
}